@@ -2,6 +2,8 @@ import time
 import pymysql
 import sqlite3
 
+from pymysql.cursors import DictCursor
+
 mysql = 'mysql'
 sqlite = 'sqlite'
 
@@ -13,14 +15,14 @@ ENGINE_DICT = {
 }
 
 class Base(object):
-
-    def __init__(self, host, user, psw, dbname,engine):
+    def __init__(self, host, user, psw, dbname,engine,charset):
         self.id = id(self)
         self._host = host
         self._user = user
         self._psw = psw
         self._dbname = dbname
         self._engine = engine
+        self._charset = charset
         self.db_engine = None
         if self._engine in ENGINE_DICT:
             self.db_engine = ENGINE_DICT[self._engine]
@@ -45,7 +47,7 @@ class Base(object):
 
     def connect(self):
         if self._engine == mysql:
-            self.db = self.db_engine.connect(self._host, self._user, self._psw, self._dbname, charset='utf8',connect_timeout=60)
+            self.db = self.db_engine.connect(self._host, self._user, self._psw, self._dbname, charset=self._charset,connect_timeout=60)
             return self.db
         if self._engine == sqlite:
             self.db = self.db_engine.connect(self._dbname)
@@ -54,6 +56,8 @@ class Base(object):
 
     def become_busy(self):
         self._is_busy = 1
+        self.last_execute_time = int(time.time())
+        self.last_connect_time = int(time.time())
         return
 
     def become_free(self):
@@ -82,11 +86,11 @@ class Base(object):
         if self._engine == sqlite:
             sql = 'PRAGMA table_info(%s)'%table
         else:
-            sql = 'show fields from ' + table
+            sql = 'show fields from ' +table
         res = self.query(sql, show_sql=False)
         if res is None:
             return
-        column_list = list(map(lambda x: x[0], res))
+        column_list = list(map(lambda x: x[0],res))
         if 'signal' in column_list:
             column_list.remove('signal')
         self._tables[table] = column_list
@@ -96,10 +100,12 @@ class Base(object):
     def _load_tables(self, show_sql=False):
         sql = 'show tables'
         res = self.query(sql, show_sql)
-        tables = tuple(map(lambda x: x[0], res))
+        # print(res)
+        tables = list(map(lambda x: x[0],res))
         # print(tables)
         for table in tables:
-            self.load_an_table(table)
+            table_name = self._dbname+'.'+table
+            self.load_an_table(table_name)
 
     def _load_all_fileds(self):
         pass
@@ -130,15 +136,13 @@ class Base(object):
         return
 
     @staticmethod
-    def find_info(table, conditions, or_cond, fields=None, group=None, order=None, limit=None):
-        # if len(fields) == 1 and fields[0] == '*':
-        #     if table in self._tables:
-        #         fields = self._tables[table]
-        #     else:
-        #         fields = self.load_an_table(table)
+    def find_info(table, conditions, or_cond, fields=None, group=None, order=None, limit=None,for_update=False):
+
         if fields is None:
             return
+
         sql = 'select %s from %s where  '%(','.join(fields), table)
+        # print(sql)
         sql,sql_params = Base.bind_conditions(sql, conditions, or_cond)
 
         if group is not None:
@@ -164,6 +168,9 @@ class Base(object):
             for i in limit:
                 sql += '%s, ' % i
             sql = sql[:-2]
+
+        if for_update is True:
+            sql += ' for update'
         return sql, sql_params
 
     @staticmethod
@@ -179,8 +186,6 @@ class Base(object):
         if len(conditions) > 0:
             for unit in conditions:
                 value = unit[2]
-                if type("") == type(value) and '(' not in value:
-                    value = "'%s'" % value
                 sql = sql + " %s %s binary "%(unit[0], unit[1]) + '%s'
                 sql_params += [value]
                 sql += "  and "
@@ -193,8 +198,6 @@ class Base(object):
         if len(or_cond) > 0:
             for unit in or_cond:
                 value = unit[2]
-                if type("") == type(value) and '(' not in value:
-                    value = "'%s'" % value
                 sql = sql + " %s %s binary "%(unit[0], unit[1]) + '%s'
                 sql_params += [value]
                 sql += "  or "
@@ -205,64 +208,69 @@ class Base(object):
         return sql,sql_params
 
     # 查找数据（单条）
-    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False):
-        sql,sql_params = self.find_info(table, conditions, or_cond, fields, None, order, None)
+    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False,for_update=False):
+        if table not in self._tables:
+            self.load_an_table(table)
+
+        if fields[0] == '*' and len(fields) == 1:
+            fieldList = self._tables[table]
+            fields = fieldList
+
+        sql,sql_params = self.find_info(table, conditions, or_cond, fields, None, order, None,for_update)
         if sql is None:
             return
 
         sql += " limit 1"
         # self.db.commit()
-        res = self.query(sql, show_sql,sql_params)
+        res = self.query(sql, show_sql,sql_params,return_dict=True)
         if res is None:
             return None
 
         if 0 == len(res):
             return None
 
-        if table not in self._tables:
-            self.load_an_table(table)
-
-        if fields[0] == '*' and len(fields) == 1:
-            fieldList = self._tables[table]
-
+        if self._engine == sqlite:
+            result = dict(zip(fields, res[0]))
         else:
-            fieldList = fields
-        # self.db.commit()
+            result = res[0]
+
         result = {
             'table':table,
-            'query':sql,
-            'result':dict(zip(fieldList, res[0]))
+            'query':sql%tuple(sql_params) if sql_params is not None else sql,
+            'result':result
         }
         return result
 
     # 查找数据
-    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False):
-        sql,sql_params = self.find_info(table, conditions, or_cond, fields, group, order, limit)
+    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,for_update=False):
+        if table not in self._tables:
+            self.load_an_table(table)
+
+        if fields[0] == '*' and len(fields) == 1:
+            fieldList = self._tables[table]
+            fields = fieldList
+
+        sql,sql_params = self.find_info(table, conditions, or_cond, fields, group, order, limit,for_update)
         if sql is None:
             return
         #
-        res = self.query(sql, show_sql,sql_params)
+        res = self.query(sql, show_sql,sql_params,return_dict=True)
         if res is None:
             return None
 
         if 0 == len(res):
             return None
 
-        if table not in self._tables:
-            self.load_an_table(table)
-
-        if fields[0] == '*' and len(fields) == 1:
-            fieldList = self._tables[table]
-        else:
-            fieldList = fields
-
         result = []
-        for data in res:
-            data = dict(zip(fieldList, data))
-            result.append(data)
+        if self._engine == sqlite:
+            for data in res:
+                data = dict(zip(fields, data))
+                result.append(data)
+        else:
+            result = res
         res = {
             'table': table,
-            'query': sql,
+            'query': sql%tuple(sql_params) if sql_params is not None else sql,
             'result': result
         }
         return res
@@ -293,14 +301,14 @@ class Base(object):
         sql = 'update %s set ' % table
         sql_params_header = []
         for param, value in params.items():
-            if type("") == type(value):
-                value = "%s" % value
             sql = sql + " %s = " % param + '%s,'
             sql_params_header += [value]
 
         sql = sql[:-1] + ' where  '
         sql,sql_params = Base.bind_conditions(sql, conditions, or_cond)
         # print(sql)
+        if sql_params == None:
+            sql_params = []
         sql_params = sql_params_header + sql_params
 
         self.query(sql, show_sql,sql_params)
@@ -308,36 +316,40 @@ class Base(object):
         return
 
     def delete(self, table, condition, or_cond, show_sql=False):
-        sql,sql_params = 'delete from %s where  ' %table
-        sql = Base.bind_conditions(sql, condition, or_cond)
+        sql = 'delete from %s where  ' %table
+        sql,sql_params = Base.bind_conditions(sql, condition, or_cond)
         #  #
-        self.query(sql, show_sql)
+        self.query(sql, show_sql,sql_params)
         return
 
-    def query(self, sql, show_sql=False,sql_params=None):
+    def query(self, sql, show_sql=False,sql_params=None,return_dict=False):
         # for i in danger_sig:
         #     if i in sql:
         #         return None
         dummy_sql = sql%tuple(sql_params) if sql_params is not None else sql
         if self._engine == sqlite:
             sql = sql.replace('binary','')
-        self.executing_query = sql
+            sql = sql.replace('%s', '?')
+        self.executing_query = dummy_sql
         if sql == 'select 1':
             show_sql = False
         if show_sql is True:
-            print(dummy_sql)
+            print('sql_id',id(self),dummy_sql)
         if self._engine != sqlite:
             try:
                 self.db.ping(reconnect=True)
             except Exception as e:
                 print(dummy_sql, 'db error', str(e), 'reconnecting...')
                 self.connect()
-        cursor = self.db.cursor()
+        if self._engine == mysql and return_dict == True:
+            cursor = self.db.cursor(DictCursor)
+        else:
+            cursor = self.db.cursor()
+
         try:
             if sql != 'select 1':
                 self.update_last_execute_time()
-            # self.update_last_execute_time()
-            self.update_last_connect_time()
+                self.update_last_connect_time()
             if sql_params is not None:
                 cursor.execute(sql,tuple(sql_params))
             else:
@@ -368,29 +380,6 @@ class Base(object):
     def get_last_connect_time(self):
         return self.last_connect_time
 
-    # def query_one(self, sql,show_sql=True):
-    #     if self._engine != sqlite:
-    #         try:
-    #             self.db.ping(reconnect=True)
-    #         except Exception as e:
-    #             print(sql, 'db error', str(e), 'reconnecting...')
-    #             self.connect()
-    #     # cur.execute(sql)
-    #     # db.commit()
-    #     if show_sql:
-    #         print(sql)
-    #     try:
-    #         cursor = self.db.cursor()
-    #         cursor.execute(sql)
-    #         self.update_last_execute_time()
-    #         results = cursor.fetchall()
-    #         if self._engine == sqlite:
-    #             self.db.commit()
-    #         return results
-    #     except Exception as e:
-    #         print(str(e))
-
-
     def truncate(self, table, show_sql=False):
         sql = 'TRUNCATE TABLE %s' % table
         self.query(sql, show_sql)
