@@ -1,7 +1,8 @@
-import asyncio
+# import asyncio
+import os
 import threading
 import time
-from ..Scheduler import IntervalTask
+# from ..Scheduler import IntervalTask
 from ..dbserver.base import Base, ENGINE_DICT, mysql
 
 # from config.config import db_config
@@ -73,13 +74,13 @@ class data_manager(object):
         #         sql.become_free()
 
 
-    def kill_unused_connection(self, kill_connect):
-        count = 0
-        for sql_id in kill_connect:
-            if sql_id in self.sql_pool:
-                self.sql_pool.pop(sql_id)
-                count += 1
-        return
+    # def kill_unused_connection(self, kill_connect):
+    #     count = 0
+    #     for sql_id in kill_connect:
+    #         if sql_id in self.sql_pool:
+    #             self.sql_pool.pop(sql_id)
+    #             count += 1
+    #     return
 
     def get_table_data(self,table,query):
         try:
@@ -94,53 +95,36 @@ class data_manager(object):
             return None
 
     def find_free_sql(self):
-        # try:
-        #     sql_list = self.sql_pool.values()
-        #     for sql in sql_list:
-        #         if sql.is_busy() is False and int(time.time()) - sql.last_execute_time < 29:
-        #             sql.become_busy()
-        #             return sql
-        # except Exception as e:
-        #     print(str(e),'查找空闲sql链接时遍历错误')
-        #     # pass
-        # print('数据库连接池全忙状态，创建新的数据库链接')
-        #
-        # sql = self.create_new_sql()
-        # sql.become_busy()
-        # self.add_new_sql(sql)
-        # print('创建完毕新连接id:', id(sql))
-        # print('数据库连接池全忙状态，创建新的数据库链接', '新连接id:', id(sql))
-        # return sql
-
-        thread_id = threading.currentThread().ident
+        # 获取当前线程绑定的sql-session
+        mypid = str(os.getpid())
+        mytid = str(threading.currentThread().ident)
+        thread_id = mypid+'.'+mytid
         # print('本次数据库请求线程id', thread_id)
-
         if thread_id in self.threading_pool:
-            if self.threading_out_time_pool[thread_id] - int(time.time()) > 30:
-                sql_id = self.threading_pool[thread_id]
-                if sql_id in self.sql_pool:
-                    sql = self.sql_pool[sql_id]
-                    sql.become_busy()
-                    self.threading_out_time_pool[thread_id] = int(time.time())
-                    return sql
+            session_status = self.threading_pool[thread_id]
+            if int(time.time()) - session_status[1] < 45:
+                session = session_status[0]
+                session.become_busy()
+                self.threading_pool[thread_id] = (session, int(time.time()))
+                return session
 
-        sql = self.create_new_sql()
-        sql.become_busy()
-        self.add_new_sql(sql)
-        self.threading_pool[thread_id] = id(sql)
-        self.threading_out_time_pool[thread_id] = int(time.time())
-        print('为线程%s更新数据库链接%s'%(thread_id,id(sql)))
-        return sql
+        session = self.create_new_sql()
+        session.become_busy()
+        # self.add_new_sql(sql)
+        self.threading_pool[thread_id] = (session,int(time.time()))
+        # self.threading_out_time_pool[thread_id] = int(time.time())
+        # print('为线程%s更新数据库链接%s'%(thread_id,id(sql)))
+        return session
 
-    def add_new_sql(self, sql):
-        self.sql_pool[id(sql)] = sql
-        return
+    # def add_new_sql(self, sql):
+    #     self.sql_pool[id(sql)] = sql
+    #     return
 
     def new(self):
         sql = self.create_new_sql()
         # print(id(sql))
-        self.add_new_sql(sql)
-        return
+        # self.add_new_sql(sql)
+        return sql
 
     def create_new_sql(self, ):
         sql = Base(self.t_data['host'], self.t_data['user'], self.t_data['password'], self.t_data['database'],self.t_data['engine'],self.t_data['charset'])
@@ -166,18 +150,18 @@ class data_manager(object):
         self.clean_table(table)
         return result
 
-    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False,from_cache = False):
+    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False,from_cache = False,for_update=False):
         sql = self.find_free_sql()
         table = self.get_table_name(table)
         if from_cache == True:
-            query,params = sql.find_info(table, conditions, or_cond, fields, None, order, None)
+            query,params = sql.find_info(table, conditions, or_cond, fields, None, order, None,for_update)
             query += " limit 1"
             query = query%params
             res = self.get_table_data(table,query)
             if res is not None:
                 sql.become_free()
                 return res
-        result = sql.find(table, conditions, or_cond, fields, order, show_sql)
+        result = sql.find(table, conditions, or_cond, fields, order, show_sql,for_update)
         if result is None:
             return
         self.mem_cache[table] = {
@@ -186,20 +170,20 @@ class data_manager(object):
         sql.become_free()
         return result['result']
 
-    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,from_cache=False):
+    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,from_cache=False,for_update=False):
         sql = self.find_free_sql()
         table = self.get_table_name(table)
         # sql.become_busy()
         # print('执行这次sql请求的链接是', id(sql))
         if from_cache == True:
-            query,params = sql.find_info(table, conditions, or_cond, fields, group, order, limit)
+            query,params = sql.find_info(table, conditions, or_cond, fields, group, order, limit,for_update)
             query = query % params
             res = self.get_table_data(table, query)
             if res is not None:
                 sql.become_free()
                 return res
 
-        result = sql.select(table, conditions, or_cond, fields, group, order, limit, show_sql)
+        result = sql.select(table, conditions, or_cond, fields, group, order, limit, show_sql,for_update)
         if result is None:
             return
         self.mem_cache[table] = {
@@ -229,12 +213,12 @@ class data_manager(object):
         sql.become_free()
         return result
 
-    def query(self, sql_query, show_sql=False):
+    def query(self, sql_query, show_sql=False,return_dict=False):
         # print(sql)
         sql = self.find_free_sql()
         # sql.become_busy()
         # print('执行这次sql请求的链接是', id(sql))
-        result = sql.query(sql_query, show_sql)
+        result = sql.query(sql_query, show_sql,return_dict=return_dict)
         sql.become_free()
         return result
 
